#include <string.h>
#include "cdbslib.h"
#include "config.h"
#include "uniqname.h"

/* SYNTABNAME -- Create new name for non-throughput synphot tables
 *
 * i: ref		reference file descriptor
 * i: reftype		reference file type
 * i: cdbsdir		the directory the reference file will be stored in
 * i: code		the instrument code number
 * o: newroot		the unique root name
 * i: maxch		maximum length of calculated name
 *
 * History:
 * 06/12/02  45993  mss   add THERMAL, THERMTAB type
 */

void syntabname (reffile *ref, char *reftype, char *cdbsdir, int code, 
		  char *newroot, int maxch)
{
    /* Check to see if this is an old (non-fits) file. If so,
     * use the old renming routine to produce the file name
     * If the reference file type is comptab or graphtab, 
     * rename the file with the substituted type. 
     */

    if (strcmp (reftype, "throughput") == 0) {
	thruname (ref, reftype, "syn", cdbsdir, newroot, maxch);

    } else if (strcmp (reftype, "thermal") == 0) {
	thruname (ref, reftype, "th", cdbsdir, newroot, maxch);

    } else if (is_fitsname (name_reffile (ref)) == NO) {
	oldinstname (cdbsdir, code, newroot, maxch);

    } else if (strcmp (reftype, "graphtab") == 0) {
	newinstname ("tmg", cdbsdir, code, newroot, maxch);

    } else if (strcmp (reftype, "comptab") == 0) {
	newinstname ("tmc", cdbsdir, code, newroot, maxch);

    } else if (strcmp (reftype, "thermtab") == 0) {
	newinstname ("tmt", cdbsdir, code, newroot, maxch);

    } else {
	newinstname (reftype, cdbsdir, code, newroot, maxch);
    }
}
